package cz.muni.sutralog.repository

import android.content.Context
import androidx.lifecycle.LiveData
import androidx.lifecycle.Transformations
import cz.muni.sutralog.data.CategoryPresentableListItem
import cz.muni.sutralog.database.CategoryDao
import cz.muni.sutralog.database.SutralogDatabase

class CategoryRepository (
    context: Context,
    private val categoryDao: CategoryDao = SutralogDatabase.create(context).categoryDao()
){

    fun saveCategory(category: CategoryPresentableListItem) {
        categoryDao.saveCategory(category.toCategoryEntity())
    }

    fun saveCategories(categories: List<CategoryPresentableListItem>) {
        categoryDao.saveCategories(categories.map { it.toCategoryEntity() })
    }

    fun getAllCategories(): LiveData<List<CategoryPresentableListItem>> {
        return Transformations.map(categoryDao.getAllCategories()) { categoryList ->
            categoryList.map {
                it.toPresentableCategoryItem()
            }
        }
    }

    fun getCategoryById(id: Long): LiveData<CategoryPresentableListItem> {
        return Transformations.map(categoryDao.getCategoryById(id)) { category -> category.toPresentableCategoryItem() }
    }

    fun deleteCategoryById(id: Long) {
        categoryDao.deleteCategoryById(id)
    }

    fun deleteCategory(category: CategoryPresentableListItem) {
        categoryDao.deleteCategory(category.toCategoryEntity())
    }
}