package cz.muni.sutralog.repository

import android.content.Context
import androidx.lifecycle.LiveData
import androidx.lifecycle.Transformations
import cz.muni.sutralog.data.RockPresentableListItem
import cz.muni.sutralog.database.RockDao
import cz.muni.sutralog.database.SutralogDatabase

class RockRepository (
    context: Context,
    private val rockDao: RockDao = SutralogDatabase.create(context).rockDao()
){
    fun saveRock(rock: RockPresentableListItem) {
        rockDao.saveRock(rock.toRockEntity())
    }

    fun saveRocks(rocks: List<RockPresentableListItem>) {
        rockDao.saveRocks(rocks.map { it.toRockEntity() })
    }

    fun getRockById(id: Long): LiveData<RockPresentableListItem> {
        return Transformations.map(rockDao.getRockById(id)) { rock -> rock.toPresentableRockItem() }
    }

    fun getAllRocks(): LiveData<List<RockPresentableListItem>> {
        return Transformations.map(rockDao.getAllRocks()) { rock ->
            rock.map { rockEntity ->
                rockEntity.toPresentableRockItem()
            }
        }
    }

    fun getRocksByCategoryId(categoryId: Long): LiveData<List<RockPresentableListItem>> {
        return Transformations.map(rockDao.getRocksByCategoryId(categoryId)) { rock ->
            rock.map { rockEntity ->
                rockEntity.toPresentableRockItem()
            }
        }
    }

    fun deleteRockById(rockId: Long) {
        rockDao.deleteRockById(rockId)
    }

    fun deleteRock(rock: RockPresentableListItem) {
        rockDao.deleteRock(rock.toRockEntity())
    }
}