package cz.muni.sutralog.ui.detail

import android.os.Bundle
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.Toast
import androidx.fragment.app.Fragment
import androidx.lifecycle.LiveData
import androidx.navigation.fragment.findNavController
import cz.muni.sutralog.R
import cz.muni.sutralog.data.RockPresentableListItem
import cz.muni.sutralog.databinding.RockDetailBinding
import cz.muni.sutralog.repository.CategoryRepository
import cz.muni.sutralog.repository.RockRepository

class RockDetailFragment : Fragment() {

    private lateinit var binding: RockDetailBinding
    private lateinit var rock : LiveData<RockPresentableListItem>

    private val rockRepository: RockRepository by lazy {
        RockRepository(requireContext())
    }

    override fun onCreateView(inflater: LayoutInflater, container: ViewGroup?, savedInstanceState: Bundle?): View {
        binding = RockDetailBinding.inflate(layoutInflater, container, false)
        return binding.root
    }

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)

        val rockId = RockDetailFragmentArgs.fromBundle(requireArguments()).rockId

        rock = rockRepository.getRockById(rockId)

        rock.observe(requireActivity()) { rockList ->
            //TODO vlozit nastavenie parametrov pre jednotlive atributy layoutu
        }

        binding.toolbar.setNavigationOnClickListener{
            findNavController().navigateUp()
        }

        binding.toolbar.setOnMenuItemClickListener {
            when (it.itemId) {
                R.id.edit -> findNavController().navigate(
                    RockDetailFragmentDirections
                        .actionRockDetailToRockEdit(rock.value!!)
                )
                R.id.remove -> {
                    rock.removeObservers(requireActivity())
                    rockRepository.deleteRock(rock.value!!)
                    findNavController().navigateUp()
                }
            }
            true
        }
    }
}