package cz.muni.sutralog.ui.list

import android.app.DatePickerDialog
import android.app.DatePickerDialog.OnDateSetListener
import android.app.Dialog
import android.graphics.Color
import android.graphics.drawable.ColorDrawable
import android.os.Bundle
import android.view.*
import android.widget.*
import androidx.appcompat.widget.SearchView
import androidx.fragment.app.Fragment
import androidx.lifecycle.LiveData
import androidx.navigation.fragment.findNavController
import cz.muni.sutralog.R
import cz.muni.sutralog.data.RockPresentableListItem
import cz.muni.sutralog.databinding.RocksListBinding
import cz.muni.sutralog.repository.RockRepository
import java.util.*


class RockListFragment : Fragment(), AdapterView.OnItemSelectedListener {

    private lateinit var binding: RocksListBinding
    private lateinit var adapter : RockAdapter
    private lateinit var selectFromDate: EditText
    private lateinit var selectToDate: EditText
    private lateinit var rocks : LiveData<List<RockPresentableListItem>>
    private var columns = arrayOf("Location", "Date", "Where")

    private val rockRepository: RockRepository by lazy {
        RockRepository(requireContext())
    }

    override fun onCreateView(inflater: LayoutInflater, container: ViewGroup?, savedInstanceState: Bundle?): View {
        binding = RocksListBinding.inflate(layoutInflater, container, false)
        return binding.root
    }

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)


        adapter = RockAdapter(
            onItemClick = {
                findNavController()
                    .navigate(RockListFragmentDirections
                        .actionRockListToRockDetail(it.id))
            },
            onItemLongClick = {
                showRockDialog(it)
            }
        )
        val searchItem = binding.toolbar.menu.findItem(R.id.search)
        val searchView = searchItem.actionView as SearchView

        searchView.setOnQueryTextListener(object : SearchView.OnQueryTextListener{
            override fun onQueryTextSubmit(query: String?): Boolean {
                return false
            }

            override fun onQueryTextChange(newText: String?): Boolean {
                adapter.filter.filter(newText)
                return false
            }
        })

        binding.toolbar.title = "Category name"
        binding.toolbar.setOnMenuItemClickListener {
            when (it.itemId) {
                R.id.filter -> showFilterDialog()
            }
            true
        }


        binding.toolbar.setNavigationOnClickListener{
            findNavController().navigateUp()
        }

        val categoryId = RockListFragmentArgs.fromBundle(requireArguments()).categoryId

        rocks = rockRepository.getRocksByCategoryId(categoryId = categoryId)

        binding.recyclerView.adapter = adapter
        rocks.observe(requireActivity()) { rockList -> adapter.submitList(rockList) }
    }

    private fun showFilterDialog() : Boolean {
        val dialog = context?.let { Dialog(it) } ?: return false
        dialog.requestWindowFeature(Window.FEATURE_NO_TITLE)
        dialog.setContentView(R.layout.bottom_sheet_filter)

        val selectFromDate = dialog.findViewById<EditText>( R.id.from_date);
        val selectToDate = dialog.findViewById<EditText>( R.id.to_date);

        selectFromDate.setOnClickListener {
            val calendar = Calendar.getInstance()
            val year = calendar.get(Calendar.YEAR)
            val month = calendar.get(Calendar.MONTH)
            val day = calendar.get(Calendar.DAY_OF_MONTH)
            val datePickerDialog = DatePickerDialog(requireContext(),R.style.DatePicker,
                OnDateSetListener { view, year, month, dayOfMonth ->
                    selectFromDate.setText(dayOfMonth.toString() + "/" + (month + 1) + "/" + year) },
                year,
                month,
                day
            )
            datePickerDialog.show()
        };

        selectToDate.setOnClickListener {
            val calendar = Calendar.getInstance()
            val year = calendar.get(Calendar.YEAR)
            val month = calendar.get(Calendar.MONTH)
            val day = calendar.get(Calendar.DAY_OF_MONTH)
            val datePickerDialog = DatePickerDialog(requireContext(),R.style.DatePicker,
                OnDateSetListener { view, year, month, dayOfMonth ->
                    selectToDate.setText(dayOfMonth.toString() + "/" + (month + 1) + "/" + year) },
                year,
                month,
                day
            )
            datePickerDialog.show()
        };

        val spin = dialog.findViewById<Spinner>(R.id.spinner)

        if(view != null){
            spin?.onItemSelectedListener = this
            val aa: ArrayAdapter<*> =
                ArrayAdapter<Any?>(requireView().context, android.R.layout.simple_spinner_item, columns)
            aa.setDropDownViewResource(android.R.layout.simple_spinner_dropdown_item)

            spin?.adapter = aa

        }

        dialog.show()
        dialog.window?.setLayout(ViewGroup.LayoutParams.MATCH_PARENT, ViewGroup.LayoutParams.WRAP_CONTENT)
        dialog.window?.setBackgroundDrawable(ColorDrawable(Color.TRANSPARENT))
        dialog.window?.attributes?.windowAnimations = R.style.DialogAnimation
        dialog.window?.setGravity(Gravity.BOTTOM)
        return true
    }

    private fun showRockDialog(item : RockPresentableListItem) : Boolean {
        val dialog = context?.let { Dialog(it) } ?: return false
        dialog.requestWindowFeature(Window.FEATURE_NO_TITLE)
        dialog.setContentView(R.layout.bs_rock_options)

        val editLayout = dialog.findViewById<LinearLayout>(R.id.edit_layout)
        val removeLayout = dialog.findViewById<LinearLayout>(R.id.remove_layout)

        editLayout.setOnClickListener {
            findNavController()
                .navigate(RockListFragmentDirections
                    .actionRockListToRockEdit(item))
            dialog.hide()
        }

        removeLayout.setOnClickListener {
            rockRepository.deleteRock(item)
            dialog.hide()
        }

        dialog.show()
        dialog.window?.setLayout(ViewGroup.LayoutParams.MATCH_PARENT, ViewGroup.LayoutParams.WRAP_CONTENT)
        dialog.window?.setBackgroundDrawable(ColorDrawable(Color.TRANSPARENT))
        dialog.window?.attributes?.windowAnimations = R.style.DialogAnimation
        dialog.window?.setGravity(Gravity.BOTTOM)
        return true
    }

    override fun onItemSelected(p0: AdapterView<*>?, p1: View?, p2: Int, p3: Long) {

    }

    override fun onNothingSelected(p0: AdapterView<*>?) {

    }
}